Base schema: http://purl.allotrope.org/json-schemas/adm/plate-reader/REC/2024/06/plate-reader.schema

Changes:

* Fixed typo in schema name `absorbance-point-detection` -> `absorbance-point-detector`
